import {LitElement, html, css} from 'lit-element';
import {customElement, query} from 'lit/decorators.js';

// const ENTER_KEY = 13;
// const ESC_KEY = 27

const TodoInputEventType = {
  SUBMIT_TODO: 'submit-todo'
};

@customElement('todo-input')
export class TodoInputElement extends LitElement {
  static styles = css`
    :host {
      display: block;
    }
  `;

  @query('input', true)
  _input!: HTMLInputElement;

  render() {
    return html`
      <input type="text"
        @keyup="${this._onkeyup}"
        @input="${this._oninput}">
    `;
  }

  private _onkeyup(event: KeyboardEvent) {
    if (event.code === 'Enter' || event.code === 'NumpadEnter') {
      this.dispatchEvent(new CustomEvent(TodoInputEventType.SUBMIT_TODO, {
        bubbles: true,
        composed: true,
        detail: this._input.value
      }));
    }
  }

  private _oninput(event: Event) {
    console.log('oninput:', event);
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'todo-input': TodoInputElement;
  }
}
