/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

import {LitElement, html, css} from 'lit';
import {customElement} from 'lit/decorators.js';

import './components/click-counter.js';
import './components/todo-input.js';

/**
 * An example element.
 *
 * @slot - This element has a slot
 * @csspart button - The button
 */
@customElement('todo-lit')
export class TodoLit extends LitElement {
  constructor() {
    super();
    this.addEventListener('submit-todo', (event: Event) => {
      console.log('submit-todo:', event);
    });
  }

  static styles = css`
    :host {
      display: block;
      padding: 16px;
    }
  `;

  render() {
    return html`
      <h1>Hello, ${this.foo()}!</h1>
      <click-counter></click-counter>
      <todo-input></todo-input>
      <slot></slot>
    `;
  }

  foo(): string {
    return 'foo';
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'todo-lit': TodoLit;
  }
}
